"use strict";

function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _classnames = _interopRequireDefault(require("classnames"));
var _bind = _interopRequireDefault(require("classnames/bind"));
var _terraHyperlink = _interopRequireDefault(require("terra-hyperlink"));
var _terraThemeContext = _interopRequireDefault(require("terra-theme-context"));
var _HeaderModule = _interopRequireDefault(require("./Header.module.scss"));
var _excluded = ["children", "title", "startContent", "endContent", "text", "level", "id", "isSubheader", "onClick", "wrapContent"];
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != _typeof(e) && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
var cx = _bind.default.bind(_HeaderModule.default);
var propTypes = {
  /**
   * IDs should be used with 'aria-labelledby' to associate headings with the corresponding page area when needing to label regions.
   * For an example, read [Accessibility Guide: Labeling Section Content](/components/terra-clinical-header/clinical-header/accessibility-guide#labeling-section-content) for additional information.
   */
  id: _propTypes.default.string,
  /**
   * Child element to be displayed on the right end of the header.
   * The element passed as children will be decorated with flex attributes.
   */
  children: _propTypes.default.element,
  /**
   * Content to be displayed at the start of the header, placed before the title
   */
  startContent: _propTypes.default.element,
  /**
   * Sets the heading level &lt;h1&gt;-&lt;h6&gt;. One of `1`, `2`, `3`, `4`, `5`, `6`. This helps screen readers to announce appropriate heading levels.
   * Changing `level` will not visually change the style of the content.
   *
   * ![IMPORTANT](https://badgen.net/badge/UX/Accessibility/blue) It is required to be set in order for the header text to have proper accessibility.
   * _Note: if the prop is not set level 1 by default. this would result in incorrect context of header in application._
   *
   * See the [Accessibility Guide](/components/terra-clinical-header/clinical-header/accessibility-guide) for additional information.
   */
  level: _propTypes.default.oneOf([1, 2, 3, 4, 5, 6]),
  /**
   * ![IMPORTANT](https://badgen.net/badge/UX/Accessibility/blue)
   * Text to be displayed as the title in the header bar.
   */
  text: _propTypes.default.string,
  /**
   * ![IMPORTANT](https://badgen.net/badge/prop/deprecated/red)
   * The `title` prop has been deprecated and will be removed in next major version release. Use the `text` prop instead.
   */
  title: _propTypes.default.string,
  /**
   * Content to be displayed at the end of the header
   * The element passed as endContent will be wrapped in a div with flex attributes.
   */
  endContent: _propTypes.default.element,
  /**
   * A Boolean indicating if element is a subheader.
   */
  isSubheader: _propTypes.default.bool,
  /**
   * Callback function triggered via hyperlink button title.
   * Sets the header title to be a hyperlink.
   */
  onClick: _propTypes.default.func,
  /**
   * A Boolean indicating if start and end content should be wrapped.
   */
  wrapContent: _propTypes.default.bool
};
var defaultProps = {
  title: '',
  startContent: null,
  endContent: null,
  isSubheader: false,
  text: '',
  wrapContent: false
};
var Header = function Header(_ref) {
  var children = _ref.children,
    title = _ref.title,
    startContent = _ref.startContent,
    endContent = _ref.endContent,
    text = _ref.text,
    level = _ref.level,
    id = _ref.id,
    isSubheader = _ref.isSubheader,
    onClick = _ref.onClick,
    wrapContent = _ref.wrapContent,
    customProps = _objectWithoutProperties(_ref, _excluded);
  var theme = (0, _react.useContext)(_terraThemeContext.default);
  if (title) {
    // TODO: remove on the next major version bump
    // eslint-disable-next-line no-console
    console.warn('The `title` prop has been renamed to `text`. Please update all references of `title` prop to `text`.');
  }
  if (!level) {
    // TODO: remove on the next major version bump
    // eslint-disable-next-line no-console
    console.warn('Default heading level may not appropriate has it would fail to convey context of heading in a site / application where it is used. Heading level should be set explicitly depending on the position of header in site / application to allow screen readers to identify headers consistently.');
  }
  var titleElement;
  var titleContent = title || text;
  if (titleContent) {
    var HeaderElement = level ? "h".concat(level) : 'h1';
    titleElement = /*#__PURE__*/_react.default.createElement("div", {
      className: cx('title-container')
    }, /*#__PURE__*/_react.default.createElement(HeaderElement, {
      id: id,
      className: cx('title')
    }, onClick ? /*#__PURE__*/_react.default.createElement(_terraHyperlink.default, {
      onClick: onClick,
      text: titleContent
    }) : titleContent));
  }
  var content = _react.default.Children.map(children, function (child) {
    return /*#__PURE__*/_react.default.cloneElement(child, {
      className: (0, _classnames.default)([cx('flex-collapse'), child.props.className])
    });
  });
  var headerClassNames = (0, _classnames.default)([cx(['flex-header', {
    subheader: isSubheader
  }, theme.className]), customProps.className]);
  var contentClassNames = wrapContent ? cx('flex-end-wrap') : cx('flex-end');
  var endClassNames = cx({
    'end-content': !title
  });
  return /*#__PURE__*/_react.default.createElement("header", _extends({}, customProps, {
    className: headerClassNames
  }), startContent && /*#__PURE__*/_react.default.createElement("div", {
    className: contentClassNames
  }, startContent), titleContent && /*#__PURE__*/_react.default.createElement("div", {
    className: cx('flex-fill')
  }, titleElement), content, endContent && /*#__PURE__*/_react.default.createElement("div", {
    className: "".concat(contentClassNames, " ").concat(endClassNames)
  }, endContent));
};
Header.propTypes = propTypes;
Header.defaultProps = defaultProps;
var _default = exports.default = Header;